import { useRouter } from "next/router";
import Link from "next/link";

import { Disclosure } from "@headlessui/react";
import { Bars3Icon, XMarkIcon } from "@heroicons/react/24/outline";

export default function Navbar() {
  const navigation = [
    { name: "Home", href: "/" },
    { name: "Frequencies", href: "/frequencies" },
    { name: "Map", href: "/map" },
    { name: "About", href: "/about" },
  ];

  const classNames = (...classes) => {
    return classes.filter(Boolean).join(" ");
  };

  const router = useRouter();

  const isCurrentRoute = (href) => {
    return router.pathname === href;
  };

  return (
    <Disclosure as="nav" className="bg-red-600">
      {({ open }) => (
        <>
          <div className="mx-auto max-w-7xl px-4 sm:px-6 lg:px-8">
            <div className="flex h-16 items-center justify-between">
              <div className="flex items-center">
                <div className="flex-shrink-0 text-white">
                  Foodborne Illness Monitoring
                </div>
                <div className="hidden md:block">
                  <div className="ml-10 flex items-baseline space-x-4">
                    {navigation.map((item) => (
                      <Link
                        key={item.name}
                        href={item.href}
                        className={classNames(
                          isCurrentRoute(item.href)
                            ? "bg-red-700 text-white"
                            : "text-white hover:bg-red-500 hover:bg-opacity-75",
                          "px-3 py-2 rounded-md text-sm font-medium"
                        )}
                        aria-current={
                          isCurrentRoute(item.href) ? "page" : undefined
                        }
                      >
                        {item.name}
                      </Link>
                    ))}
                  </div>
                </div>
              </div>
              <div className="-mr-2 flex md:hidden">
                {/* Mobile menu button */}
                <Disclosure.Button className="inline-flex items-center justify-center rounded-md bg-red-700 p-2 text-red-200 hover:bg-red-500 hover:bg-opacity-75 hover:text-white focus:outline-none focus:ring-2 focus:ring-white focus:ring-offset-2 focus:ring-offset-red-600">
                  <span className="sr-only">Open main menu</span>
                  {open ? (
                    <XMarkIcon className="block h-6 w-6" aria-hidden="true" />
                  ) : (
                    <Bars3Icon className="block h-6 w-6" aria-hidden="true" />
                  )}
                </Disclosure.Button>
              </div>
            </div>
          </div>

          <Disclosure.Panel className="md:hidden">
            <div className="space-y-1 px-2 pt-2 pb-3 sm:px-3">
              {navigation.map((item) => (
                <Disclosure.Button
                  key={item.name}
                  as="a"
                  href={item.href}
                  className={classNames(
                    isCurrentRoute(item.href)
                      ? "bg-red-700 text-white"
                      : "text-white hover:bg-red-500 hover:bg-opacity-75",
                    "block px-3 py-2 rounded-md text-base font-medium"
                  )}
                  aria-current={isCurrentRoute(item.href) ? "page" : undefined}
                >
                  {item.name}
                </Disclosure.Button>
              ))}
            </div>
          </Disclosure.Panel>
        </>
      )}
    </Disclosure>
  );
}
