import React, { useRef, useEffect, useState } from "react";
import * as d3 from "d3";

import { useD3 } from "../../hooks/useD3";

import { Colors } from "../../lib/Colors/colors";

const WIDTH = 736;
const GRAPH_HEIGHT = 450;
const TIMELINE_HEIGHT = 100;

const MARGIN = { top: 70, right: 0, bottom: 20, left: 50 };

const START_DATE = new Date(2016, 0);
const END_DATE = new Date(2023, 4);

const Joy = ({ type }) => {
  const colors = new Colors();

  const graphRef = useD3(
    (svgRaw) => {
      svgRaw.selectAll("*").remove();
      const width = WIDTH - MARGIN.left - MARGIN.right,
        height = GRAPH_HEIGHT - MARGIN.top - MARGIN.bottom;

      svgRaw
        .attr("width", width + MARGIN.left + MARGIN.right)
        .attr("height", height + MARGIN.top + MARGIN.bottom);

      const svg = svgRaw
        .append("g")
        .attr("transform", `translate(${MARGIN.left}, ${MARGIN.top})`);

      console.log("type", type);

      fetch(`${process.env.NEXT_PUBLIC_BACKEND_URL}/${type}`, {
        method: "GET",
        headers: {
          "ngrok-skip-browser-warning": "any",
        },
      })
        .then((response) => {
          console.log("response", response);
          return response.json();
        })
        .then((data) => {
          // d3.json(`${process.env.NEXT_PUBLIC_BACKEND_URL}/${type}`).then((data) => {
          console.log("data", data);
          const categories = Object.keys(data);
          console.log(categories);

          const x = (d) => d.timestamp;
          const xScale = d3
            .scaleTime()
            .domain([START_DATE, END_DATE])
            .range([0, width]);

          const y = (d) => d.value;
          const yScale = d3.scaleLinear().domain([0, 350]).range([height, 0]);

          svg
            .append("g")
            .attr("transform", `translate(${MARGIN.left}, ${height})`)
            .call(d3.axisBottom(xScale))
            .style("color", "black");

          const yName = d3
            .scaleBand()
            .domain(categories)
            .range([0, height])
            .paddingInner(1);

          svg
            .append("g")
            .attr("transform", `translate(${MARGIN.left}, 0)`)
            .call(d3.axisLeft(yName))
            .style("color", "black");

          // Add areas
          categories.forEach((category) => {
            const area = d3
              .area()
              .curve(d3.curveBasis)
              .x(function (d) {
                return xScale(x(d));
              })
              .y1(function (d) {
                return yScale(y(d));
              })
              .y0(yScale(0));

            svg
              .append("path")
              .datum(data[category])
              .attr("transform", function (d) {
                return `translate(${MARGIN.left}, ${yName(category) - height})`;
              })
              .attr("stroke", "#000")
              .attr("stroke-width", 1)
              .attr("d", area)
              .attr("fill", () => colors.nextColor());
          });

          svg
            .selectAll("text")
            .attr("fill", "black")
            .attr("style", "font-size: 12px; color: black;");
        });
    },
    [type]
  ); // eslint-disable-line react-hooks/exhaustive-deps

  return (
    <div>
      <div className="joy-container">
        <svg
          ref={graphRef}
          style={{ boxShadow: "0px -0px 10000px transparent" }}
        />
      </div>
    </div>
  );
};

export default Joy;
