import React, { useRef, useEffect, useState } from "react";
import { createRoot } from "react-dom/client";

import mapboxgl from "mapbox-gl";

import Posts from "./Posts";

const MAPBOX_ACCESS_TOKEN =
  "pk.eyJ1Ijoid2VyamtsZXdyIiwiYSI6ImNsZTRucDF1NDA0c3kzdnQ5dXZieWpmbGEifQ.aQWs4dtpvz3YMmzaL5J3Qw";
const MAPBOX_STYLE = "mapbox://styles/werjklewr/cle4nvbna004601mui9232b3z";

const DEFAULT_LNG = -97.9429;
const DEFAULT_LAT = 38.4284;
const DEFAULT_ZOOM = 3.8;

const USA_BOUNDS: mapboxgl.LngLatBoundsLike = [-179, 18.1287, -50, 89];

const DENSITY_LAYER = "outbreaks";

const PROJECTION: mapboxgl.Projection = {
  name: "mercator",
};

mapboxgl.accessToken = MAPBOX_ACCESS_TOKEN;

const generatePopupText = (feature) => {
  return `<div><h6>${feature.properties.id}</h6><p>${feature.properties.text}</p></div>`;
};

const Density = () => {
  const mapContainerRef = useRef(null);

  const [lng, setLng] = useState(DEFAULT_LNG);
  const [lat, setLat] = useState(DEFAULT_LAT);
  const [zoom, setZoom] = useState(DEFAULT_ZOOM);

  const [points, setPoints] = useState("[]");

  // Initialize map when component mounts
  useEffect(() => {
    const map = new mapboxgl.Map({
      container: mapContainerRef.current,
      style: MAPBOX_STYLE,
      center: [lng, lat],
      zoom: zoom,
      minZoom: DEFAULT_ZOOM,
      maxBounds: USA_BOUNDS,
      projection: PROJECTION,
    });

    // Add navigation control (the +/- zoom buttons)
    map.addControl(new mapboxgl.NavigationControl(), "top-right");

    map.on("move", () => {
      setLng(Number(map.getCenter().lng.toFixed(4)));
      setLat(Number(map.getCenter().lat.toFixed(4)));
      setZoom(Number(map.getZoom().toFixed(2)));
    });

    map.on("click", DENSITY_LAYER, (e) => {
      setPoints(JSON.stringify(e.features));
      console.log(
        "features length",
        e.features.length,
        [...e.features],
        points
      );
      const coordinates = e.features[0].geometry["coordinates"].slice();

      // const description = generatePopupText(e.features[0]);

      while (Math.abs(e.lngLat.lng - coordinates[0]) > 180) {
        coordinates[0] += e.lngLat.lng > coordinates[0] ? 360 : -360;
      }

      const postsNode = document.createElement("div");
      const postsRoot = createRoot(postsNode);
      console.log("here");
      postsRoot.render(<Posts points={JSON.stringify(e.features)} />);

      new mapboxgl.Popup()
        .setLngLat(coordinates)
        .setDOMContent(postsNode)
        .addTo(map);
    });

    // Clean up on unmount
    return () => map.remove();
  }, [points]); // eslint-disable-line react-hooks/exhaustive-deps

  return (
    <div>
      <div>
        <div>
          Longitude: {lng} | Latitude: {lat} | Zoom: {zoom}
        </div>
      </div>
      <div className="map-container" ref={mapContainerRef} />
    </div>
  );
};

export default Density;
